This location is for your Act's own static files
They will be collected (along with others)
using python manage.py collectstatic -l into ./cstatic (STATIC_ROOT)
and deployed at STATIC_URL

TODO: create a folder with the name of the act here